
From: Corey Minyard <minyard@acm.org>

This adds MODULE_VERSION, MODULE_DESCRIPTION, and MODULE_AUTHOR tags to the
IPMI driver modules.  Also changes the MODULE_VERSION to remove the
prepended 'v' on each value, consistent with the module versioning policy.

This patch also removes all the version information from everything except
the ipmi_msghandler module.

Signed-off-by: Matt Domsch <Matt_Domsch@dell.com>
Signed-off-by: Corey Minyard <minyard@acm.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 drivers/char/ipmi/ipmi_bt_sm.c      |    3 ---
 drivers/char/ipmi/ipmi_devintf.c    |    7 +++----
 drivers/char/ipmi/ipmi_kcs_sm.c     |    3 ---
 drivers/char/ipmi/ipmi_msghandler.c |    8 ++++++--
 drivers/char/ipmi/ipmi_poweroff.c   |    6 +++---
 drivers/char/ipmi/ipmi_si_intf.c    |   14 +++-----------
 drivers/char/ipmi/ipmi_smic_sm.c    |    3 ---
 drivers/char/ipmi/ipmi_watchdog.c   |    9 ++++-----
 8 files changed, 19 insertions(+), 34 deletions(-)

diff -puN drivers/char/ipmi/ipmi_bt_sm.c~ipmi-clean-up-versioning-of-the-ipmi-driver drivers/char/ipmi/ipmi_bt_sm.c
--- 25/drivers/char/ipmi/ipmi_bt_sm.c~ipmi-clean-up-versioning-of-the-ipmi-driver	Wed Aug 17 13:51:34 2005
+++ 25-akpm/drivers/char/ipmi/ipmi_bt_sm.c	Wed Aug 17 13:51:34 2005
@@ -31,8 +31,6 @@
 #include <linux/ipmi_msgdefs.h>		/* for completion codes */
 #include "ipmi_si_sm.h"
 
-#define IPMI_BT_VERSION "v33"
-
 static int bt_debug = 0x00;	/* Production value 0, see following flags */
 
 #define	BT_DEBUG_ENABLE	1
@@ -501,7 +499,6 @@ static int bt_size(void)
 
 struct si_sm_handlers bt_smi_handlers =
 {
-	.version           = IPMI_BT_VERSION,
 	.init_data         = bt_init_data,
 	.start_transaction = bt_start_transaction,
 	.get_result        = bt_get_result,
diff -puN drivers/char/ipmi/ipmi_devintf.c~ipmi-clean-up-versioning-of-the-ipmi-driver drivers/char/ipmi/ipmi_devintf.c
--- 25/drivers/char/ipmi/ipmi_devintf.c~ipmi-clean-up-versioning-of-the-ipmi-driver	Wed Aug 17 13:51:34 2005
+++ 25-akpm/drivers/char/ipmi/ipmi_devintf.c	Wed Aug 17 13:51:34 2005
@@ -47,8 +47,6 @@
 #include <linux/device.h>
 #include <linux/compat.h>
 
-#define IPMI_DEVINTF_VERSION "v33"
-
 struct ipmi_file_private
 {
 	ipmi_user_t          user;
@@ -822,8 +820,7 @@ static __init int init_ipmi_devintf(void
 	if (ipmi_major < 0)
 		return -EINVAL;
 
-	printk(KERN_INFO "ipmi device interface version "
-	       IPMI_DEVINTF_VERSION "\n");
+	printk(KERN_INFO "ipmi device interface\n");
 
 	ipmi_class = class_create(THIS_MODULE, "ipmi");
 	if (IS_ERR(ipmi_class)) {
@@ -866,3 +863,5 @@ static __exit void cleanup_ipmi(void)
 module_exit(cleanup_ipmi);
 
 MODULE_LICENSE("GPL");
+MODULE_AUTHOR("Corey Minyard <minyard@mvista.com>");
+MODULE_DESCRIPTION("Linux device interface for the IPMI message handler.");
diff -puN drivers/char/ipmi/ipmi_kcs_sm.c~ipmi-clean-up-versioning-of-the-ipmi-driver drivers/char/ipmi/ipmi_kcs_sm.c
--- 25/drivers/char/ipmi/ipmi_kcs_sm.c~ipmi-clean-up-versioning-of-the-ipmi-driver	Wed Aug 17 13:51:34 2005
+++ 25-akpm/drivers/char/ipmi/ipmi_kcs_sm.c	Wed Aug 17 13:51:34 2005
@@ -42,8 +42,6 @@
 #include <linux/ipmi_msgdefs.h>		/* for completion codes */
 #include "ipmi_si_sm.h"
 
-#define IPMI_KCS_VERSION "v33"
-
 /* Set this if you want a printout of why the state machine was hosed
    when it gets hosed. */
 #define DEBUG_HOSED_REASON
@@ -489,7 +487,6 @@ static void kcs_cleanup(struct si_sm_dat
 
 struct si_sm_handlers kcs_smi_handlers =
 {
-	.version           = IPMI_KCS_VERSION,
 	.init_data         = init_kcs_data,
 	.start_transaction = start_kcs_transaction,
 	.get_result        = get_kcs_result,
diff -puN drivers/char/ipmi/ipmi_msghandler.c~ipmi-clean-up-versioning-of-the-ipmi-driver drivers/char/ipmi/ipmi_msghandler.c
--- 25/drivers/char/ipmi/ipmi_msghandler.c~ipmi-clean-up-versioning-of-the-ipmi-driver	Wed Aug 17 13:51:34 2005
+++ 25-akpm/drivers/char/ipmi/ipmi_msghandler.c	Wed Aug 17 13:51:34 2005
@@ -47,7 +47,8 @@
 #include <linux/proc_fs.h>
 
 #define PFX "IPMI message handler: "
-#define IPMI_MSGHANDLER_VERSION "v33"
+
+#define IPMI_DRIVER_VERSION "36.0"
 
 static struct ipmi_recv_msg *ipmi_alloc_recv_msg(void);
 static int ipmi_init_msghandler(void);
@@ -3150,7 +3151,7 @@ static int ipmi_init_msghandler(void)
 		return 0;
 
 	printk(KERN_INFO "ipmi message handler version "
-	       IPMI_MSGHANDLER_VERSION "\n");
+	       IPMI_DRIVER_VERSION "\n");
 
 	for (i=0; i<MAX_IPMI_INTERFACES; i++) {
 		ipmi_interfaces[i] = NULL;
@@ -3222,6 +3223,9 @@ module_exit(cleanup_ipmi);
 
 module_init(ipmi_init_msghandler_mod);
 MODULE_LICENSE("GPL");
+MODULE_AUTHOR("Corey Minyard <minyard@mvista.com>");
+MODULE_DESCRIPTION("Incoming and outgoing message routing for an IPMI interface.");
+MODULE_VERSION(IPMI_DRIVER_VERSION);
 
 EXPORT_SYMBOL(ipmi_create_user);
 EXPORT_SYMBOL(ipmi_destroy_user);
diff -puN drivers/char/ipmi/ipmi_poweroff.c~ipmi-clean-up-versioning-of-the-ipmi-driver drivers/char/ipmi/ipmi_poweroff.c
--- 25/drivers/char/ipmi/ipmi_poweroff.c~ipmi-clean-up-versioning-of-the-ipmi-driver	Wed Aug 17 13:51:34 2005
+++ 25-akpm/drivers/char/ipmi/ipmi_poweroff.c	Wed Aug 17 13:51:34 2005
@@ -42,7 +42,6 @@
 #include <linux/ipmi_smi.h>
 
 #define PFX "IPMI poweroff: "
-#define IPMI_POWEROFF_VERSION	"v33"
 
 /* Where to we insert our poweroff function? */
 extern void (*pm_power_off)(void);
@@ -582,8 +581,7 @@ static int ipmi_poweroff_init (void)
 	struct proc_dir_entry *file;
 
 	printk ("Copyright (C) 2004 MontaVista Software -"
-		" IPMI Powerdown via sys_reboot version "
-		IPMI_POWEROFF_VERSION ".\n");
+		" IPMI Powerdown via sys_reboot.\n");
 
 	switch (poweroff_control) {
 		case IPMI_CHASSIS_POWER_CYCLE:
@@ -642,3 +640,5 @@ module_exit(ipmi_poweroff_cleanup);
 
 module_init(ipmi_poweroff_init);
 MODULE_LICENSE("GPL");
+MODULE_AUTHOR("Corey Minyard <minyard@mvista.com>");
+MODULE_DESCRIPTION("IPMI Poweroff extension to sys_reboot");
diff -puN drivers/char/ipmi/ipmi_si_intf.c~ipmi-clean-up-versioning-of-the-ipmi-driver drivers/char/ipmi/ipmi_si_intf.c
--- 25/drivers/char/ipmi/ipmi_si_intf.c~ipmi-clean-up-versioning-of-the-ipmi-driver	Wed Aug 17 13:51:34 2005
+++ 25-akpm/drivers/char/ipmi/ipmi_si_intf.c	Wed Aug 17 13:51:34 2005
@@ -77,8 +77,6 @@ static inline void add_usec_to_timer(str
 #include <linux/init.h>
 #include <linux/dmi.h>
 
-#define IPMI_SI_VERSION "v33"
-
 /* Measure times between events in the driver. */
 #undef DEBUG_TIMING
 
@@ -2310,15 +2308,7 @@ static __init int init_ipmi_si(void)
 		}
 	}
 
-	printk(KERN_INFO "IPMI System Interface driver version "
-	       IPMI_SI_VERSION);
-	if (kcs_smi_handlers.version)
-		printk(", KCS version %s", kcs_smi_handlers.version);
-	if (smic_smi_handlers.version)
-		printk(", SMIC version %s", smic_smi_handlers.version);
-	if (bt_smi_handlers.version)
-   	        printk(", BT version %s", bt_smi_handlers.version);
-	printk("\n");
+	printk(KERN_INFO "IPMI System Interface driver.\n");
 
 #ifdef CONFIG_X86
 	dmi_find_bmc();
@@ -2430,3 +2420,5 @@ static __exit void cleanup_ipmi_si(void)
 module_exit(cleanup_ipmi_si);
 
 MODULE_LICENSE("GPL");
+MODULE_AUTHOR("Corey Minyard <minyard@mvista.com>");
+MODULE_DESCRIPTION("Interface to the IPMI driver for the KCS, SMIC, and BT system interfaces.");
diff -puN drivers/char/ipmi/ipmi_smic_sm.c~ipmi-clean-up-versioning-of-the-ipmi-driver drivers/char/ipmi/ipmi_smic_sm.c
--- 25/drivers/char/ipmi/ipmi_smic_sm.c~ipmi-clean-up-versioning-of-the-ipmi-driver	Wed Aug 17 13:51:34 2005
+++ 25-akpm/drivers/char/ipmi/ipmi_smic_sm.c	Wed Aug 17 13:51:34 2005
@@ -46,8 +46,6 @@
 #include <linux/ipmi_msgdefs.h>		/* for completion codes */
 #include "ipmi_si_sm.h"
 
-#define IPMI_SMIC_VERSION "v33"
-
 /* smic_debug is a bit-field
  *	SMIC_DEBUG_ENABLE -	turned on for now
  *	SMIC_DEBUG_MSG -	commands and their responses
@@ -588,7 +586,6 @@ static int smic_size(void)
 
 struct si_sm_handlers smic_smi_handlers =
 {
-	.version           = IPMI_SMIC_VERSION,
 	.init_data         = init_smic_data,
 	.start_transaction = start_smic_transaction,
 	.get_result        = smic_get_result,
diff -puN drivers/char/ipmi/ipmi_watchdog.c~ipmi-clean-up-versioning-of-the-ipmi-driver drivers/char/ipmi/ipmi_watchdog.c
--- 25/drivers/char/ipmi/ipmi_watchdog.c~ipmi-clean-up-versioning-of-the-ipmi-driver	Wed Aug 17 13:51:34 2005
+++ 25-akpm/drivers/char/ipmi/ipmi_watchdog.c	Wed Aug 17 13:51:34 2005
@@ -53,8 +53,6 @@
 
 #define	PFX "IPMI Watchdog: "
 
-#define IPMI_WATCHDOG_VERSION "v33"
-
 /*
  * The IPMI command/response information for the watchdog timer.
  */
@@ -928,9 +926,6 @@ static int __init ipmi_wdog_init(void)
 {
 	int rv;
 
-	printk(KERN_INFO PFX "driver version "
-	       IPMI_WATCHDOG_VERSION "\n");
-
 	if (strcmp(action, "reset") == 0) {
 		action_val = WDOG_TIMEOUT_RESET;
 	} else if (strcmp(action, "none") == 0) {
@@ -1015,6 +1010,8 @@ static int __init ipmi_wdog_init(void)
 	register_reboot_notifier(&wdog_reboot_notifier);
 	notifier_chain_register(&panic_notifier_list, &wdog_panic_notifier);
 
+	printk(KERN_INFO PFX "driver initialized\n");
+
 	return 0;
 }
 
@@ -1066,3 +1063,5 @@ static void __exit ipmi_wdog_exit(void)
 module_exit(ipmi_wdog_exit);
 module_init(ipmi_wdog_init);
 MODULE_LICENSE("GPL");
+MODULE_AUTHOR("Corey Minyard <minyard@mvista.com>");
+MODULE_DESCRIPTION("watchdog timer based upon the IPMI interface.");
_
